translate.misc.dictutils.cidict

Package translate :: Package misc :: Module dictutils :: Class cidict |
[hide private]
[frames] | no frames]

# Class cidict

source code

Instance Methods | [hide private]
    new empty dictionary
__init__(self, fromdict=None) constructs the cidict, optionally using another dict to do so | source code
__getitem__(self, key) x[y] | source code
__setitem__(self, key, value) x[i]=y | source code
None |
update(D, E) Update D from E: for k in E.keys(): D[k] = E[k] | source code
__delitem__(self, key) del x[y] | source code
True if D has a key k, else False |
__contains__(self, key) | source code
True if D has a key k, else False |
has_key(self, key) | source code
D[k] if k in D, else d |
get(self, key, default=None) d defaults to None. | source code
Inherited from `dict`: `__cmp__`, `__eq__`, `__ge__`, `__getattribute__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__ne__`, `__new__`, `__repr__`, `__sizeof__`, `clear`, `copy`, `fromkeys`, `items`, `iteritems`, `iterkeys`, `itervalues`, `keys`, `pop`, `popitem`, `setdefault`, `values` Inherited from `object`: `__delattr__`, `__format__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `dict`: `__hash__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, fromdict=None) (Constructor) | source code
constructs the cidict, optionally using another dict to do so Returns:
    new empty dictionary
Overrides: object.__init__

### __getitem__(self, key) (Indexing operator) | source code
x[y] Overrides: dict.__getitem__ (inherited documentation)

### __setitem__(self, key, value) (Index assignment operator) | source code
x[i]=y Overrides: dict.__setitem__ (inherited documentation)

### update(D, E) | source code
Update D from E: for k in E.keys(): D[k] = E[k] Returns: None Overrides: dict.update

### __delitem__(self, key) (Index deletion operator) | source code
del x[y] Overrides: dict.__delitem__ (inherited documentation)

### __contains__(self, key) (In operator) | source code
Returns: True if D has a key k, else False Overrides: dict.__contains__ (inherited documentation)

### has_key(self, key) | source code
Returns: True if D has a key k, else False Overrides: dict.has_key (inherited documentation)

### get(self, key, default=None) | source code
d defaults to None. Returns: D[k] if k in D, else d Overrides: dict.get (inherited documentation)